Documentation
¶
Index ¶
- Constants
- Variables
- func Kind(kind string) schema.GroupKind
- func Resource(resource string) schema.GroupResource
- type ControllerConfiguration
- type DurosConfiguration
- type DurosPartitionConfiguration
- type DurosSeedStorageClass
- type ETCD
- type ETCDBackup
- type ETCDStorage
- type ImagePullSecret
- type MachineImage
- type NetpolsIngressController
- type NetworkPolicies
- type StorageConfiguration
Constants ¶
const GroupName = "metal.provider.extensions.config.gardener.cloud"
GroupName is the group name use in this package
Variables ¶
var ( // SchemeBuilder used to register the Shoot resource. SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) // AddToScheme is a pointer to SchemeBuilder.AddToScheme. AddToScheme = SchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: runtime.APIVersionInternal}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type ControllerConfiguration ¶
type ControllerConfiguration struct {
metav1.TypeMeta
// ClientConnection specifies the kubeconfig file and client connection
// settings for the proxy server to use when communicating with the apiserver.
ClientConnection *configv1alpha1.ClientConnectionConfiguration
// MachineImages is the list of machine images that are understood by the controller. It maps
// logical names and versions to metal-specific identifiers, i.e. AMIs.
MachineImages []MachineImage
// FirewallInternalPrefixes is a list of prefixes for the firewall-controller
// which will be counted as internal network traffic. this is important for accounting
// networking traffic.
FirewallInternalPrefixes []string
// ETCD is the etcd configuration.
ETCD ETCD
// HealthCheckConfig is the config for the health check controller
HealthCheckConfig *healthcheckconfig.HealthCheckConfig
// Storage is the configuration for storage.
Storage StorageConfiguration
// ImagePullPolicy defines the pull policy for the components deployed through the control plane controller.
// Defaults to IfNotPresent if empty or unknown.
ImagePullPolicy string
// ImagePullSecret provides an opportunity to inject an image pull secret into the resource deployments
ImagePullSecret *ImagePullSecret
// NetworkPolicies contains extra configuration for network policies
NetworkPolicies *NetworkPolicies
}
ControllerConfiguration defines the configuration for the metal provider.
func (*ControllerConfiguration) DeepCopy ¶
func (in *ControllerConfiguration) DeepCopy() *ControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ControllerConfiguration.
func (*ControllerConfiguration) DeepCopyInto ¶
func (in *ControllerConfiguration) DeepCopyInto(out *ControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ControllerConfiguration) DeepCopyObject ¶
func (in *ControllerConfiguration) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type DurosConfiguration ¶ added in v0.15.1
type DurosConfiguration struct {
// Enabled enables duros storage when set to true.
Enabled bool
// PartitionConfig is a map of a partition id to the duros partition configuration
PartitionConfig map[string]DurosPartitionConfiguration
}
DurosConfiguration contains the configuration for lightbits duros storage.
func (*DurosConfiguration) DeepCopy ¶ added in v0.15.1
func (in *DurosConfiguration) DeepCopy() *DurosConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DurosConfiguration.
func (*DurosConfiguration) DeepCopyInto ¶ added in v0.15.1
func (in *DurosConfiguration) DeepCopyInto(out *DurosConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DurosPartitionConfiguration ¶ added in v0.16.11
type DurosPartitionConfiguration struct {
// Endpoints is the list of endpoints for the storage data plane and control plane communication
Endpoints []string
// AdminKey is the key used for generating storage credentials
AdminKey string
// AdminToken is the token used by the duros-controller to authenticate against the duros API
AdminToken string
// StorageClasses contain information on the storage classes that the duros-controller creates in the shoot cluster
StorageClasses []DurosSeedStorageClass
// APIEndpoint is the endpoint used for control plane network communication.
APIEndpoint string
// APICA is the ca of the client cert to access the api endpoint
APICA string
// APICert is the cert of the client cert to access the api endpoint
APICert string
// APIKey is the key of the client cert to access the api endpoint
APIKey string
}
DurosPartitionConfiguration is the configuration for duros for a particular partition
func (*DurosPartitionConfiguration) DeepCopy ¶ added in v0.16.11
func (in *DurosPartitionConfiguration) DeepCopy() *DurosPartitionConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DurosPartitionConfiguration.
func (*DurosPartitionConfiguration) DeepCopyInto ¶ added in v0.16.11
func (in *DurosPartitionConfiguration) DeepCopyInto(out *DurosPartitionConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DurosSeedStorageClass ¶ added in v0.15.1
type DurosSeedStorageClass struct {
// Name is the name of the storage class
Name string
// ReplicaCount is the amount of replicas in the storage backend for this storage class
ReplicaCount int
// Compression enables compression for this storage class
Compression bool
// Encryption defines a SC with client side encryption enabled
Encryption bool
}
func (*DurosSeedStorageClass) DeepCopy ¶ added in v0.15.1
func (in *DurosSeedStorageClass) DeepCopy() *DurosSeedStorageClass
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DurosSeedStorageClass.
func (*DurosSeedStorageClass) DeepCopyInto ¶ added in v0.15.1
func (in *DurosSeedStorageClass) DeepCopyInto(out *DurosSeedStorageClass)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ETCD ¶
type ETCD struct {
// ETCDStorage is the etcd storage configuration.
Storage ETCDStorage
// ETCDBackup is the etcd backup configuration.
Backup ETCDBackup
// EvictionAllowed is a flag to allow deletion of the etcd pvc through the csi-driver-lvm-controller
IsEvictionAllowed bool
}
ETCD is an etcd configuration.
func (*ETCD) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ETCD.
func (*ETCD) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ETCDBackup ¶
type ETCDBackup struct {
// Schedule is the etcd backup schedule.
Schedule *string
// DeltaSnapshotPeriod is the time for delta snapshots to be made
DeltaSnapshotPeriod *string
}
ETCDBackup is an etcd backup configuration.
func (*ETCDBackup) DeepCopy ¶
func (in *ETCDBackup) DeepCopy() *ETCDBackup
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ETCDBackup.
func (*ETCDBackup) DeepCopyInto ¶
func (in *ETCDBackup) DeepCopyInto(out *ETCDBackup)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ETCDStorage ¶
type ETCDStorage struct {
// ClassName is the name of the storage class used in etcd-main volume claims.
ClassName *string
// Capacity is the storage capacity used in etcd-main volume claims.
Capacity *resource.Quantity
}
ETCDStorage is an etcd storage configuration.
func (*ETCDStorage) DeepCopy ¶
func (in *ETCDStorage) DeepCopy() *ETCDStorage
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ETCDStorage.
func (*ETCDStorage) DeepCopyInto ¶
func (in *ETCDStorage) DeepCopyInto(out *ETCDStorage)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ImagePullSecret ¶ added in v0.15.6
type ImagePullSecret struct {
// DockerConfigJSON contains the already base64 encoded JSON content for the image pull secret
DockerConfigJSON string
}
ImagePullSecret provides an opportunity to inject an image pull secret into the resource deployments
func (*ImagePullSecret) DeepCopy ¶ added in v0.15.6
func (in *ImagePullSecret) DeepCopy() *ImagePullSecret
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ImagePullSecret.
func (*ImagePullSecret) DeepCopyInto ¶ added in v0.15.6
func (in *ImagePullSecret) DeepCopyInto(out *ImagePullSecret)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MachineImage ¶
type MachineImage struct {
// Name is the logical name of the machine image.
Name string
// Version is the logical version of the machine image.
Version string
// Image is the path to the image.
Image string
}
MachineImage is a mapping from logical names and versions to GCP-specific identifiers.
func (*MachineImage) DeepCopy ¶
func (in *MachineImage) DeepCopy() *MachineImage
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MachineImage.
func (*MachineImage) DeepCopyInto ¶
func (in *MachineImage) DeepCopyInto(out *MachineImage)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type NetpolsIngressController ¶ added in v0.27.7
type NetpolsIngressController struct {
// Namespace is the namespace of the ingress-controller
Namespace string
// PodSelector is the pod selector for the ingress-controller pods
PodSelector map[string]string
}
NetpolsIngressController contains extra configuration for network policies regarding an ingress-controller
func (*NetpolsIngressController) DeepCopy ¶ added in v0.27.7
func (in *NetpolsIngressController) DeepCopy() *NetpolsIngressController
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NetpolsIngressController.
func (*NetpolsIngressController) DeepCopyInto ¶ added in v0.27.7
func (in *NetpolsIngressController) DeepCopyInto(out *NetpolsIngressController)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type NetworkPolicies ¶ added in v0.27.7
type NetworkPolicies struct {
// IngressController contains extra configuration for network policies regarding an ingress-controller
IngressController *NetpolsIngressController
}
NetworkPolicies contains extra configuration for network policies
func (*NetworkPolicies) DeepCopy ¶ added in v0.27.7
func (in *NetworkPolicies) DeepCopy() *NetworkPolicies
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NetworkPolicies.
func (*NetworkPolicies) DeepCopyInto ¶ added in v0.27.7
func (in *NetworkPolicies) DeepCopyInto(out *NetworkPolicies)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type StorageConfiguration ¶ added in v0.15.1
type StorageConfiguration struct {
// Duros contains the configuration for duros cloud storage
Duros DurosConfiguration
}
StorageConfiguration contains the configuration for provider specific storage solutions.
func (*StorageConfiguration) DeepCopy ¶ added in v0.15.1
func (in *StorageConfiguration) DeepCopy() *StorageConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new StorageConfiguration.
func (*StorageConfiguration) DeepCopyInto ¶ added in v0.15.1
func (in *StorageConfiguration) DeepCopyInto(out *StorageConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.